require 'uu/os/rest/dto'
require 'uu/os/uesuri'

module UU
  module Fairpay2
    module Account
      # Value object containing attributes of a Client Account entity.
      class ClientAccountAttributes < UU::OS::REST::DTO

        # URI of the Client Account.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :uri

        # URI of meta artifact of created Client Account.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :meta_artifact_uri

        # Name of created Client Account.
        # @param [String]
        # @return [String]
        attr_accessor :name

        # Code of created Client Account.
        # @param [String]
        # @return [String]
        attr_accessor :code

        # Description of created Client Account.
        # @param [String]
        # @return [String]
        attr_accessor :description

        # URI of the role competent for created Client Account.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :competent_role_uri

        # URI of container of the Client Account.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :location_uri

        # URI of organizational unit of the Client Account.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :organizational_unit_uri

        # Security level of the Client Account.
        # @param [UU::OS::Artifact::SecurityLevel]
        # @return [UU::OS::Artifact::SecurityLevel]
        attr_accessor :security_level

        # Creation stamp of the Client Account.
        # @param [String, Time]
        # @return [String]
        attr_accessor :creation_stamp

        # Creation time of the Client Account.
        # @param [String, Time]
        # @return [String]
        attr_accessor :creation_time

        # Modification stamp of the Client Account.
        # @param [String, Time]
        # @return [String]
        attr_accessor :modification_stamp

        # Modification time of the Client Account.
        # @param [String, Time]
        # @return [String]
        attr_accessor :modification_time

        # Version of the Client Account.
        # @param [String]
        # @return [String]
        attr_accessor :version

        # Name of current state of the Client Account.
        # @param [String]
        # @return [String]
        attr_accessor :state_name

        # Comment of current state of the Client Account.
        # @param [String]
        # @return [String]
        attr_accessor :state_comment

        # Type of current state of the Client Account.
        # @param [UU::OS::Artifact::ArtifactStateType]
        # @return [UU::OS::Artifact::ArtifactStateType]
        attr_accessor :state_type

        # Flag of width of sheets of the Client Account.
        # @param [UU::OS::Artifact::ArtifactWidthType]
        # @return [UU::OS::Artifact::ArtifactWidthType]
        attr_accessor :width

        # UESURI of the entity type of the artifact
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :entity_type_uri

        # URI of the icon of the Client Account.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :icon_uri

        # URI of Company.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :company_uri

        # Account number for created client account.
        # @param [String]
        # @return [String]
        attr_accessor :account_number

        # Account currency for created client account.
        # @param [String]
        # @return [String]
        attr_accessor :account_currency

        def uri
          attributes[:uri]
        end

        def uri=(val)
          if val
            attributes[:uri] = UU::OS::UESURI.new(val)
          else
            attributes[:uri] = nil
          end
        end

        def meta_artifact_uri
          attributes[:metaArtifactUri]
        end

        def meta_artifact_uri=(val)
          if val
            attributes[:metaArtifactUri] = UU::OS::UESURI.new(val)
          else
            attributes[:metaArtifactUri] = nil
          end
        end

        def name
          attributes[:name]
        end

        def name=(val)
          attributes[:name] = val
        end

        def code
          attributes[:code]
        end

        def code=(val)
          attributes[:code] = val
        end

        def description
          attributes[:description]
        end

        def description=(val)
          attributes[:description] = val
        end

        def competent_role_uri
          attributes[:competentRoleUri]
        end

        def competent_role_uri=(val)
          if val
            attributes[:competentRoleUri] = UU::OS::UESURI.new(val)
          else
            attributes[:competentRoleUri] = nil
          end
        end

        def location_uri
          attributes[:locationUri]
        end

        def location_uri=(val)
          if val
            attributes[:locationUri] = UU::OS::UESURI.new(val)
          else
            attributes[:locationUri] = nil
          end
        end

        def organizational_unit_uri
          attributes[:organizationalUnitUri]
        end

        def organizational_unit_uri=(val)
          if val
            attributes[:organizationalUnitUri] = UU::OS::UESURI.new(val)
          else
            attributes[:organizationalUnitUri] = nil
          end
        end

        def security_level
          attributes[:securityLevel]
        end

        def security_level=(val)
          attributes[:securityLevel] = val
        end

        def creation_stamp
          attributes[:creationStamp]
        end

        def creation_stamp=(val)
          attributes[:creationStamp] = val
        end

        def creation_time
          attributes[:creationTime]
        end

        def creation_time=(val)
          attributes[:creationTime] = val
        end

        def modification_stamp
          attributes[:modificationStamp]
        end

        def modification_stamp=(val)
          attributes[:modificationStamp] = val
        end

        def modification_time
          attributes[:modificationTime]
        end

        def modification_time=(val)
          attributes[:modificationTime] = val
        end

        def version
          attributes[:version]
        end

        def version=(val)
          attributes[:version] = val
        end

        def state_name
          attributes[:stateName]
        end

        def state_name=(val)
          attributes[:stateName] = val
        end

        def state_comment
          attributes[:stateComment]
        end

        def state_comment=(val)
          attributes[:stateComment] = val
        end

        def state_type
          attributes[:stateType]
        end

        def state_type=(val)
          attributes[:stateType] = val
        end

        def width
          attributes[:width]
        end

        def width=(val)
          attributes[:width] = val
        end

        def icon_uri
          attributes[:iconUri]
        end

        def icon_uri=(val)
          if val
            attributes[:iconUri] = UU::OS::UESURI.new(val)
          else
            attributes[:iconUri] = nil
          end
        end

        def entity_type_uri
          attributes[:entityTypeUri]
        end

        def entity_type_uri=(val)
          if val
            attributes[:entityTypeUri] = UU::OS::UESURI.new(val)
          else
            attributes[:entityTypeUri] = nil
          end
        end

        def company_uri
          attributes[:companyUri]
        end

        def company_uri=(val)
          if val
            attributes[:companyUri] = UU::OS::UESURI.new(val)
          else
            attributes[:companyUri] = nil
          end
        end

        def account_number
          attributes[:accountNumber]
        end

        def account_number=(val)
          attributes[:accountNumber] = val
        end

        def account_currency
          attributes[:accountCurrency]
        end

        def account_currency=(val)
          attributes[:accountCurrency] = val
        end

      end
    end
  end
end

