require 'uu/os/rest/dto'
require 'uu/os/uesuri'

module UU
  module Fairpay2
    module Account
      # Value object containing attributes to create a Client Account entity.
      class ClientAccountCreate < UU::OS::REST::DTO

        # Name of created client account.
        # <p>Cannot be null nor empty string nor longer than 250 characters and can contain only allowed characters.
        # The create command fails otherwise.
        # @param [String]
        # @return [String]
        attr_accessor :name

        # Code of created client account.
        # <p>The code must be unique in target territory. It cannot be empty string nor longer than 250 characters and can contain only allowed characters.
        # The create command will fail otherwise. When null is set, the code is generated automatically.
        # @param [String]
        # @return [String]
        attr_accessor :code

        # Description of created client account. Cannot be longer than 4000 characters.
        # @param [String]
        # @return [String]
        attr_accessor :description

        # URI of the role competent for created client account.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :competent_role_uri

        # Security level.
        # @param [UU::OS::Artifact::SecurityLevel]
        # @return [UU::OS::Artifact::SecurityLevel]
        attr_accessor :security_level

        # URI of meta artifact of created Client Account.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :meta_artifact_uri

        # URI of Company. Cannot be null.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :company_uri

        # Account number for created client account. Cannot be longer than 250 characters and cannot be null.
        # @param [String]
        # @return [String]
        attr_accessor :account_number

        # Account currency for created client account. Cannot be longer than 250 characters and cannot be null.
        # @param [String]
        # @return [String]
        attr_accessor :account_currency

        def name
          attributes[:name]
        end

        def name=(val)
          attributes[:name] = val
        end


        def code
          attributes[:code]
        end

        def code=(val)
          attributes[:code] = val
        end


        def description
          attributes[:description]
        end

        def description=(val)
          attributes[:description] = val
        end


        def competent_role_uri
          attributes[:competentRoleUri]
        end

        def competent_role_uri=(val)
          if val
            attributes[:competentRoleUri] = UU::OS::UESURI.new(val)
          else
            attributes[:competentRoleUri] = nil
          end
        end

        def security_level
          attributes[:securityLevel]
        end

        def security_level=(val)
          attributes[:securityLevel] = val
        end

        def meta_artifact_uri
          attributes[:metaArtifactUri]
        end

        def meta_artifact_uri=(val)
          if val
            attributes[:metaArtifactUri] = UU::OS::UESURI.new(val)
          else
            attributes[:metaArtifactUri] = nil
          end
        end

        def company_uri
          attributes[:companyUri]
        end

        def company_uri=(val)
          if val
            attributes[:companyUri] = UU::OS::UESURI.new(val)
          else
            attributes[:companyUri] = nil
          end
        end

        def account_number
          attributes[:accountNumber]
        end

        def account_number=(val)
          attributes[:accountNumber] = val
        end

        def account_currency
          attributes[:accountCurrency]
        end

        def account_currency=(val)
          attributes[:accountCurrency] = val
        end

      end
    end
  end
end

