require 'uu/os/rest/dto'
require 'uu/os/uesuri'

module UU
  module Fairpay2
    module BusinessCase

      # Value object defining data required (available) for creating new Client Account Business Case entity.
      class ClientAccountBusinessCaseCreate < UU::OS::REST::DTO

        # Name of created Client Account Business Case.
        # The value is trimmed. If null is set, the name is taken from the meta artifact.
        # @param [String]
        # @return [String]
        attr_accessor :name

        # Code of created Client Account Business Case.
        # The value is trimmed. If null is set, the code is generated automatically.
        # @param [String]
        # @return [String]
        attr_accessor :code

        # Description of created client account business case.
        # Cannot be longer than 4000 characters.
        # @param [String]
        # @return [String]
        attr_accessor :description

        # URI of meta artifact of created Client Account.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :meta_artifact_uri

        # URI of the role competent for created client account business case.
        # Cannot be null or longer than 4000 characters. Must be valid UESURI.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :competent_role_uri

        # Security level.
        # @param [UU::OS::Artifact::SecurityLevel]
        # @return [UU::OS::Artifact::SecurityLevel]
        attr_accessor :security_level

        # User universe id of client.
        # Required attribute, cannot be null or longer than 250 characters.
        # @param [String]
        # @return [String]
        attr_accessor :user_universe_id

        # Daily withdrawal limit of the related Account.
        # Required attribute, cannot be null or invalid Fixnum.
        # @param [Fixnum]
        # @return [Fixnum]
        attr_accessor :daily_limit

        # Weekly withdrawal limit of the related Account.
        # Required attribute, cannot be null or invalid Fixnum.
        # @param [Fixnum]
        # @return [Fixnum]
        attr_accessor :weekly_limit

        # Monthly withdrawal limit of the related Account.
        # Required attribute, cannot be null or invalid Fixnum.
        # @param [Fixnum]
        # @return [Fixnum]
        attr_accessor :monthly_limit

        # Account number of the client.
        # Required attribute, cannot be null or longer than 250 characters.
        # @param [String]
        # @return [String]
        attr_accessor :client_account_number

        # Client uuEE universe id on Client Account Business Case.
        # Required attribute, cannot be null or longer than 4000 characters.
        # @param [String]
        # @return [String]
        attr_accessor :client_uuee_universe_id

        # Avalible balance on Client Account Business Case.
        # Required attribute, cannot be null or invalid Fixnum.
        # @param [Fixnum]
        # @return [Fixnum]
        attr_accessor :available_balance

        # Current balance on Client Account Business Case.
        # Required attribute, cannot be null or invalid Fixnum.
        # @param [Fixnum]
        # @return [Fixnum]
        attr_accessor :current_balance

        # Authorized Persons on Client Account Business Case.
        # Required attribute, cannot be null or longer than 4000 characters.
        # @param [String]
        # @return [String]
        attr_accessor :authorized_persons

        # Authorized Accounts on Client Account Business Case.
        # Required attribute, cannot be null or longer than 4000 characters.
        # @param [String]
        # @return [String]
        attr_accessor :authorized_accounts

        # Currency code on Client Account Business Case.
        # Required attribute, cannot be null or longer than 250 characters.
        # @param [String]
        # @return [String]
        attr_accessor :currency_code


        def name
          attributes[:name]
        end

        def name=(val)
          attributes[:name] = val
        end


        def code
          attributes[:code]
        end

        def code=(val)
          attributes[:code] = val
        end


        def description
          attributes[:description]
        end

        def description=(val)
          attributes[:description] = val
        end

        def meta_artifact_uri
          attributes[:metaArtifactUri]
        end

        def meta_artifact_uri=(val)
          if val
            attributes[:metaArtifactUri] = UU::OS::UESURI.new(val)
          else
            attributes[:metaArtifactUri] = nil
          end
        end

        def competent_role_uri
          attributes[:competentRoleUri]
        end

        def competent_role_uri=(val)
          if val
            attributes[:competentRoleUri] = UU::OS::UESURI.new(val)
          else
            attributes[:competentRoleUri] = nil
          end
        end


        def user_universe_id
          attributes[:userUniverseId]
        end

        def user_universe_id=(val)
          attributes[:userUniverseId] = val
        end


        def daily_limit
          attributes[:dailyLimit]
        end

        def daily_limit=(val)
          attributes[:dailyLimit] = val
        end


        def weekly_limit
          attributes[:weeklyLimit]
        end

        def weekly_limit=(val)
          attributes[:weeklyLimit] = val
        end


        def monthly_limit
          attributes[:monthlyLimit]
        end

        def monthly_limit=(val)
          attributes[:monthlyLimit] = val
        end


        def client_account_number
          attributes[:clientAccountNumber]
        end

        def client_account_number=(val)
          attributes[:clientAccountNumber] = val
        end


        def client_uuee_universe_id
          attributes[:clientUueeUniverseId]
        end

        def client_uuee_universe_id=(val)
          attributes[:clientUueeUniverseId] = val
        end


        def available_balance
          attributes[:availableBalance]
        end

        def available_balance=(val)
          attributes[:availableBalance] = val
        end


        def current_balance
          attributes[:currentBalance]
        end

        def current_balance=(val)
          attributes[:currentBalance] = val
        end


        def authorized_persons
          attributes[:authorizedPersons]
        end

        def authorized_persons=(val)
          attributes[:authorizedPersons] = val
        end


        def authorized_accounts
          attributes[:authorizedAccounts]
        end

        def authorized_accounts=(val)
          attributes[:authorizedAccounts] = val
        end

        def security_level
          attributes[:securityLevel]
        end

        def security_level=(val)
          attributes[:securityLevel] = val
        end

        def currency_code
          attributes[:currencyCode]
        end

        def currency_code=(val)
          attributes[:currencyCode] = val
        end

      end
    end
  end
end

