require 'uu/os/rest/dto'
require 'uu/os/uesuri'

module UU
  module Fairpay2
    module BusinessCase
      # Value object representing data  to set Client Account Business Case entity.
      class ClientAccountBusinessCaseSetAttributes < UU::OS::REST::DTO

        # Name of created Client Account Business Case.
        # The value is trimmed. If null is set, the name is taken from the meta artifact.
        # @param [String]
        # @return [String]
        attr_accessor :name

        # Code of created Client Account Business Case.
        # The value is trimmed. If null is set, the code is generated automatically.
        # @param [String]
        # @return [String]
        attr_accessor :code

        # Description of created client account business case.
        # Cannot be whitespaces longer than 4000 characters.
        # @param [String]
        # @return [String]
        attr_accessor :description

        # User universe id of client.
        # Cannot be whitespaces or longer than 250 characters.
        # @param [String]
        # @return [String]
        attr_accessor :user_universe_id

        # Daily withdrawal limit of the related Account.
        # Cannot be whitespaces or invalid Fixnum.
        # @param [Fixnum]
        # @return [Fixnum]
        attr_accessor :daily_limit

        # Weekly withdrawal limit of the related Account.
        # Cannot be whitespaces or invalid Fixnum.
        # @param [Fixnum]
        # @return [Fixnum]
        attr_accessor :weekly_limit

        # Monthly withdrawal limit of the related Account.
        # Cannot be whitespaces or invalid Fixnum.
        # @param [Fixnum]
        # @return [Fixnum]
        attr_accessor :monthly_limit

        # Account number of the client.
        # Cannot be whitespaces or longer than 250 characters.
        # @param [String]
        # @return [String]
        attr_accessor :client_account_number

        # Client uuEE universe id on Client Account Business Case.
        # Cannot be whitespaces or longer than 4000 characters.
        # @param [String]
        # @return [String]
        attr_accessor :client_uuee_universe_id

        # Avalible balance on Client Account Business Case.
        # Cannot be whitespaces or invalid Fixnum.
        # @param [Fixnum]
        # @return [Fixnum]
        attr_accessor :available_balance

        # Current balance on Client Account Business Case.
        # Cannot be whitespaces or invalid Fixnum.
        # @param [Fixnum]
        # @return [Fixnum]
        attr_accessor :current_balance

        # Authorized Persons on Client Account Business Case.
        # Cannot be whitespaces or longer than 4000 characters.
        # @param [String]
        # @return [String]
        attr_accessor :authorized_persons

        # Authorized Accounts on Client Account Business Case.
        # Cannot be whitespaces or longer than 4000 characters.
        # @param [String]
        # @return [String]
        attr_accessor :authorized_accounts

        # Currency code on Client Account Business Case.
        # Cannot be whitespaces or longer than 250 characters.
        # @param [String]
        # @return [String]
        attr_accessor :currency_code


        def name
          attributes[:name]
        end

        def name=(val)
          attributes[:name] = val
        end

        def code
          attributes[:code]
        end

        def code=(val)
          attributes[:code] = val
        end

        def description
          attributes[:description]
        end

        def description=(val)
          attributes[:description] = val
        end

        def user_universe_id
          attributes[:userUniverseId]
        end

        def user_universe_id=(val)
          attributes[:userUniverseId] = val
        end

        def daily_limit
          attributes[:dailyLimit]
        end

        def daily_limit=(val)
          attributes[:dailyLimit] = val
        end

        def weekly_limit
          attributes[:weeklyLimit]
        end

        def weekly_limit=(val)
          attributes[:weeklyLimit] = val
        end

        def monthly_limit
          attributes[:monthlyLimit]
        end

        def monthly_limit=(val)
          attributes[:monthlyLimit] = val
        end

        def client_account_number
          attributes[:clientAccountNumber]
        end

        def client_account_number=(val)
          attributes[:clientAccountNumber] = val
        end

        def client_uuee_universe_id
          attributes[:clientUueeUniverseId]
        end

        def client_uuee_universe_id=(val)
          attributes[:clientUueeUniverseId] = val
        end

        def available_balance
          attributes[:availableBalance]
        end

        def available_balance=(val)
          attributes[:availableBalance] = val
        end

        def current_balance
          attributes[:currentBalance]
        end

        def current_balance=(val)
          attributes[:currentBalance] = val
        end

        def authorized_persons
          attributes[:authorizedPersons]
        end

        def authorized_persons=(val)
          attributes[:authorizedPersons] = val
        end

        def authorized_accounts
          attributes[:authorizedAccounts]
        end

        def authorized_accounts=(val)
          attributes[:authorizedAccounts] = val
        end

        def currency_code
          attributes[:currencyCode]
        end

        def currency_code=(val)
          attributes[:currencyCode] = val
        end

      end
    end
  end
end

