require 'uu/os/rest/dto'
require 'uu/os/uesuri'

module UU
  module Fairpay2
    module FinancialTransaction
      class BankTransactionAttributes < UU::OS::REST::DTO

        # Name of the bank transaction.
        # @param [String]
        # @return [String]
        attr_accessor :name

        # Code of the bank transaction.
        # @param [String]
        # @return [String]
        attr_accessor :code

        # Description of the bank transaction.
        # @param [String]
        # @return [String]
        attr_accessor :description

        # URI of the bank transaction.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :uri

        # URI of organizational unit of the bank transaction.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :organizational_unit_uri

        # URI of the meta artifact of the bank transaction.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :meta_artifact_uri

        # URI of role competent for the bank transaction.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :competent_role_uri

        # Security level of the bank transaction.
        # @param [UU::OS::Artifact::SecurityLevel]
        # @return [UU::OS::Artifact::SecurityLevel]
        attr_accessor :security_level

        # Creation stamp of the bank transaction.
        # @param [String, Time]
        # @return [String]
        attr_accessor :creation_stamp

        # Creation time of the bank transaction.
        # @param [String, Time]
        # @return [String]
        attr_accessor :creation_time

        # Modification stamp of the bank transaction.
        # @param [String, Time]
        # @return [String]
        attr_accessor :modification_stamp

        # Modification time of the bank transaction.
        # @param [String, Time]
        # @return [String]
        attr_accessor :modification_time

        # Version of the bank transaction.
        # @param [String]
        # @return [String]
        attr_accessor :version

        # Name of current state of the bank transaction.
        # @param [String]
        # @return [String]
        attr_accessor :state_name

        # Comment of current state of the bank transaction.
        # @param [String]
        # @return [String]
        attr_accessor :state_comment

        # Type of current state of the bank transaction.
        # @param [UU::OS::Artifact::ArtifactStateType]
        # @return [UU::OS::Artifact::ArtifactStateType]
        attr_accessor :state_type

        # Flag of width of sheets of the bank transaction.
        # @param [UU::OS::Artifact::ArtifactWidthType]
        # @return [UU::OS::Artifact::ArtifactWidthType]
        attr_accessor :width

        # URI of the icon of the bank transaction.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :icon_uri

        # URI of the entity type of the bank transaction.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :entity_type_uri

        # Amount of the Bank Transaction.
        # @param [Fixnum]
        # @return [Fixnum]
        attr_accessor :amount

        # Constant symbol.
        # @param [String]
        # @return [String]
        attr_accessor :constant_symbol

        # UESURI of the credit business case or Client Account Business Case.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :credit_business_case_uri

        # Currency code.
        # @param [String]
        # @return [String]
        attr_accessor :currency

        # UESURI of the debit business case or Client Account Business Case.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :debit_business_case_uri

        # Specific symbol.
        # @param [String]
        # @return [String]
        attr_accessor :specific_symbol

        # Variable symbol.
        # @param [String]
        # @return [String]
        attr_accessor :variable_symbol

        # Message for recipient.
        # @param [String]
        # @return [String]
        attr_accessor :message_recipient

        # Message for payer.
        # @param [String]
        # @return [String]
        attr_accessor :message_payer

        # Uri of Finman transaction. UESURI must be normalized.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :finman_transaction_uri

        # Uri of org. unit or folder where we want to create Finman transaction. Attribute is required.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :location_uri

        # Credit Client Account Number
        # @param [String]
        # @return [String]
        attr_accessor :credit_account_number

        # Debit Client Account Number
        # @param [String]
        # @return [String]
        attr_accessor :debit_account_number

        # Credit Account Currency
        # @param [String]
        # @return [String]
        attr_accessor :credit_account_currency

        # Debit Account Currency
        # @param [String]
        # @return [String]
        attr_accessor :debit_account_currency

        # Exchange rate for opposite side.
        # @param [Fixnum]
        # @return [Fixnum]
        attr_accessor :exchange_rate_for_opp_side

        # Amount for opposite side
        # @param [Fixnum]
        # @return [Fixnum]
        attr_accessor :amount_for_opp_side

        def name
          attributes[:name]
        end

        def name=(val)
          attributes[:name] = val
        end

        def code
          attributes[:code]
        end

        def code=(val)
          attributes[:code] = val
        end

        def description
          attributes[:description]
        end

        def description=(val)
          attributes[:description] = val
        end

        def uri
          attributes[:uri]
        end

        def uri=(val)
          if val
            attributes[:uri] = UU::OS::UESURI.new(val)
          else
            attributes[:uri] = nil
          end
        end

        def location_uri
          attributes[:locationUri]
        end

        def location_uri=(val)
          if val
            attributes[:locationUri] = UU::OS::UESURI.new(val)
          else
            attributes[:locationUri] = nil
          end
        end

        def organizational_unit_uri
          attributes[:organizationalUnitUri]
        end

        def organizational_unit_uri=(val)
          if val
            attributes[:organizationalUnitUri] = UU::OS::UESURI.new(val)
          else
            attributes[:organizationalUnitUri] = nil
          end
        end

        def meta_artifact_uri
          attributes[:metaArtifactUri]
        end

        def meta_artifact_uri=(val)
          if val
            attributes[:metaArtifactUri] = UU::OS::UESURI.new(val)
          else
            attributes[:metaArtifactUri] = nil
          end
        end

        def competent_role_uri
          attributes[:competentRoleUri]
        end

        def competent_role_uri=(val)
          if val
            attributes[:competentRoleUri] = UU::OS::UESURI.new(val)
          else
            attributes[:competentRoleUri] = nil
          end
        end

        def security_level
          attributes[:securityLevel]
        end

        def security_level=(val)
          attributes[:securityLevel] = val
        end

        def creation_stamp
          attributes[:creationStamp]
        end

        def creation_stamp=(val)
          attributes[:creationStamp] = val
        end

        def creation_time
          attributes[:creationTime]
        end

        def creation_time=(val)
          attributes[:creationTime] = val
        end

        def modification_stamp
          attributes[:modificationStamp]
        end

        def modification_stamp=(val)
          attributes[:modificationStamp] = val
        end

        def modification_time
          attributes[:modificationTime]
        end

        def modification_time=(val)
          attributes[:modificationTime] = val
        end

        def version
          attributes[:version]
        end

        def version=(val)
          attributes[:version] = val
        end

        def state_name
          attributes[:stateName]
        end

        def state_name=(val)
          attributes[:stateName] = val
        end

        def state_comment
          attributes[:stateComment]
        end

        def state_comment=(val)
          attributes[:stateComment] = val
        end

        def state_type
          attributes[:stateType]
        end

        def state_type=(val)
          attributes[:stateType] = val
        end

        def width
          attributes[:width]
        end

        def width=(val)
          attributes[:width] = val
        end

        def icon_uri
          attributes[:iconUri]
        end

        def icon_uri=(val)
          if val
            attributes[:iconUri] = UU::OS::UESURI.new(val)
          else
            attributes[:iconUri] = nil
          end
        end

        def entity_type_uri
          attributes[:entityTypeUri]
        end

        def entity_type_uri=(val)
          if val
            attributes[:entityTypeUri] = UU::OS::UESURI.new(val)
          else
            attributes[:entityTypeUri] = nil
          end
        end

        def amount
          attributes[:amount]
        end

        def amount=(val)
          attributes[:amount] = val
        end

        def constant_symbol
          attributes[:constantSymbol]
        end

        def constant_symbol=(val)
          attributes[:constantSymbol] = val
        end

        def currency
          attributes[:currency]
        end

        def currency=(val)
          attributes[:currency] = val
        end

        def credit_business_case_uri
          attributes[:creditBusinessCaseUri]
        end

        def credit_business_case_uri=(val)
          if val
            attributes[:creditBusinessCaseUri] = UU::OS::UESURI.new(val)
          else
            attributes[:creditBusinessCaseUri] = nil
          end
        end

        def debit_business_case_uri
          attributes[:debitBusinessCaseUri]
        end

        def debit_business_case_uri=(val)
          if val
            attributes[:debitBusinessCaseUri] = UU::OS::UESURI.new(val)
          else
            attributes[:debitBusinessCaseUri] = nil
          end
        end

        def specific_symbol
          attributes[:specificSymbol]
        end

        def specific_symbol=(val)
          attributes[:specificSymbol] = val
        end

        def variable_symbol
          attributes[:variableSymbol]
        end

        def variable_symbol=(val)
          attributes[:variableSymbol] = val
        end

        def message_recipient
          attributes[:messageRecipient]
        end

        def message_recipient=(val)
          attributes[:messageRecipient] = val
        end

        def credit_account_number
          attributes[:creditAccountNumber]
        end

        def credit_account_number=(val)
          attributes[:creditAccountNumber] = val
        end

        def debit_account_number
          attributes[:debitAccountNumber]
        end

        def debit_account_number=(val)
          attributes[:debitAccountNumber] = val
        end

        def message_payer
          attributes[:messagePayer]
        end

        def message_payer=(val)
          attributes[:messagePayer] = val
        end

        def finman_transaction_uri
          attributes[:finmanTransactionUri]
        end

        def finman_transaction_uri=(val)
          if val
            attributes[:finmanTransactionUri] = UU::OS::UESURI.new(val)
          else
            attributes[:finmanTransactionUri] = nil
          end
        end



        def credit_account_currency
          attributes[:creditAccountCurrency]
        end

        def credit_account_currency=(val)
          attributes[:creditAccountCurrency] = val
        end


        def debit_account_currency
          attributes[:debitAccountCurrency]
        end

        def debit_account_currency=(val)
          attributes[:debitAccountCurrency] = val
        end


        def exchange_rate_for_opp_side
          attributes[:exchangeRateForOppSide]
        end

        def exchange_rate_for_opp_side=(val)
          attributes[:exchangeRateForOppSide] = val
        end


        def amount_for_opp_side
          attributes[:amountForOppSide]
        end

        def amount_for_opp_side=(val)
          attributes[:amountForOppSide] = val
        end

      end
    end
  end
end

