require 'uu/os/rest/dto'
require 'uu/os/uesuri'

module UU
  module Fairpay2
    module FinancialTransaction

      class BankTransactionSetAttributes < UU::OS::REST::DTO

        # Name of the bank transaction.
        # The value is trimmed. If null is set, the name is taken from the meta artifact.
        # @param [String]
        # @return [String]
        attr_accessor :name

        # Code of the bank transaction.
        # The value is trimmed. If null is set, the code is generated automatically.
        # @param [String]
        # @return [String]
        attr_accessor :code

        # Description of the Bank Transaction.
        # @param [String]
        # @return [String]
        attr_accessor :description

        # Amount of the Bank Transaction.
        # @param [Fixnum]
        # @return [Fixnum]
        attr_accessor :amount

        # Constant symbol.
        # @param [String]
        # @return [String]
        attr_accessor :constant_symbol

        # Specific symbol.
        # @param [String]
        # @return [String]
        attr_accessor :specific_symbol

        # Variable symbol.
        # @param [String]
        # @return [String]
        attr_accessor :variable_symbol

        # Message for recipient.
        # @param [String]
        # @return [String]
        attr_accessor :message_recipient

        # Message for payer.
        # @param [String]
        # @return [String]
        attr_accessor :message_payer

        # Uri of Finman transaction. UESURI must be normalized. Attribute is not required. <b>Should be used only
        # in integration script FINMAN->FAIRPAY </b>
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :finman_transaction_uri

        # Credit Client Account Number
        # @param [String]
        # @return [String]
        attr_accessor :credit_account_number

        # Debit Client Account Number
        # @param [String]
        # @return [String]
        attr_accessor :debit_account_number

        # Credit Account Currency
        # @param [String]
        # @return [String]
        attr_accessor :credit_account_currency

        # Debit Account Currency
        # @param [String]
        # @return [String]
        attr_accessor :debit_account_currency

        # Exchange rate for opposite side.
        # @param [Fixnum]
        # @return [Fixnum]
        attr_accessor :exchange_rate_for_opp_side

        # Amount for opposite side
        # @param [Fixnum]
        # @return [Fixnum]
        attr_accessor :amount_for_opp_side


        def name
          attributes[:name]
        end

        def name=(val)
          attributes[:name] = val
        end


        def code
          attributes[:code]
        end

        def code=(val)
          attributes[:code] = val
        end


        def description
          attributes[:description]
        end

        def description=(val)
          attributes[:description] = val
        end


        def amount
          attributes[:amount]
        end

        def amount=(val)
          attributes[:amount] = val
        end


        def constant_symbol
          attributes[:constantSymbol]
        end

        def constant_symbol=(val)
          attributes[:constantSymbol] = val
        end


        def specific_symbol
          attributes[:specificSymbol]
        end

        def specific_symbol=(val)
          attributes[:specificSymbol] = val
        end


        def variable_symbol
          attributes[:variableSymbol]
        end

        def variable_symbol=(val)
          attributes[:variableSymbol] = val
        end


        def message_recipient
          attributes[:messageRecipient]
        end

        def message_recipient=(val)
          attributes[:messageRecipient] = val
        end


        def message_payer
          attributes[:messagePayer]
        end

        def message_payer=(val)
          attributes[:messagePayer] = val
        end


        def finman_transaction_uri
          attributes[:finmanTransactionUri]
        end

        def finman_transaction_uri=(val)
          if val
            attributes[:finmanTransactionUri] = UU::OS::UESURI.new(val)
          else
            attributes[:finmanTransactionUri] = nil
          end
        end

        def credit_account_number
          attributes[:creditAccountNumber]
        end

        def credit_account_number=(val)
          attributes[:creditAccountNumber] = val
        end


        def debit_account_number
          attributes[:debitAccountNumber]
        end

        def debit_account_number=(val)
          attributes[:debitAccountNumber] = val
        end


        def credit_account_currency
          attributes[:creditAccountCurrency]
        end

        def credit_account_currency=(val)
          attributes[:creditAccountCurrency] = val
        end


        def debit_account_currency
          attributes[:debitAccountCurrency]
        end

        def debit_account_currency=(val)
          attributes[:debitAccountCurrency] = val
        end


        def exchange_rate_for_opp_side
          attributes[:exchangeRateForOppSide]
        end

        def exchange_rate_for_opp_side=(val)
          attributes[:exchangeRateForOppSide] = val
        end


        def amount_for_opp_side
          attributes[:amountForOppSide]
        end

        def amount_for_opp_side=(val)
          attributes[:amountForOppSide] = val
        end

      end
    end
  end
end

